@@ -12,15 +12,15 @@ options(width=90,
 
 
 ###################################################
-### code chunk number 2: yll.rnw:30-31 (eval = FALSE)
+### code chunk number 2: yll.rnw:31-33
 ###################################################
-## source("../r/boxes.MS.R")
+anfang <- Sys.time()
+cat("Start time:", format(anfang, "%F, %T"), "\n")
 
 
 ###################################################
 ### code chunk number 3: states
 ###################################################
-getOption("SweaveHooks")[["fig"]]()
 library(Epi)
 TM <- matrix(NA, 4, 4)
 rownames(TM) <-
@@ -35,7 +35,6 @@ zz <- boxes(TM, boxpos = list(x = c(20, 80, 20, 80),
 ###################################################
 ### code chunk number 4: states
 ###################################################
-getOption("SweaveHooks")[["fig"]]()
 zz$Arrowtext <- c(expression(lambda),
                   expression(mu[W]),
                   expression(mu[D][M]))
@@ -43,20 +42,20 @@ boxes.MS(zz)
 
 
 ###################################################
-### code chunk number 5: yll.rnw:275-276
+### code chunk number 5: yll.rnw:278-279
 ###################################################
 data(DMepi)
 
 
 ###################################################
-### code chunk number 6: yll.rnw:282-284
+### code chunk number 6: yll.rnw:285-287
 ###################################################
 str(DMepi)
 head(DMepi)
 
 
 ###################################################
-### code chunk number 7: yll.rnw:304-310
+### code chunk number 7: yll.rnw:307-313
 ###################################################
 DMepi <- transform(subset(DMepi, A > 30),
                    A = A + 0.5,
@@ -67,7 +66,7 @@ head(DMepi)
 
 
 ###################################################
-### code chunk number 8: yll.rnw:316-341
+### code chunk number 8: yll.rnw:319-344
 ###################################################
 # Knots used in all models
 (a.kn <- seq(40, 95, , 6))
@@ -97,7 +96,7 @@ lW.f <- update(lW.m, data = subset(DMepi, sex == "F"))
 
 
 ###################################################
-### code chunk number 9: yll.rnw:348-385
+### code chunk number 9: yll.rnw:351-388
 ###################################################
 a.ref <- 30:90
 p.ref <- 1996:2016
@@ -141,7 +140,6 @@ round(ftable(aYLL[, , seq(1, 61, 10), ], col.vars=c(3, 2)), 1)
 ###################################################
 ### code chunk number 10: imm
 ###################################################
-getOption("SweaveHooks")[["fig"]]()
 plyll <- function(wh, xtxt){
 par(mfrow = c(1, 2),
       mar = c(3, 3, 1, 1),
@@ -174,14 +172,21 @@ plyll("Imm", " - immunity assumption")
 ###################################################
 ### code chunk number 11: tot
 ###################################################
-getOption("SweaveHooks")[["fig"]]()
 plyll("Tot", " - total mortality refernce")
 
 
 ###################################################
 ### code chunk number 12: sus
 ###################################################
-getOption("SweaveHooks")[["fig"]]()
 plyll("Sus", " - susceptibility assumed")
 
 
+###################################################
+### code chunk number 13: yll.rnw:471-475
+###################################################
+ende <- Sys.time()
+cat("  Start time:", format(anfang, "%F, %T"), "\n")
+cat("    End time:", format(  ende, "%F, %T"), "\n")
+cat("Elapsed time:", round(difftime(ende, anfang, units = "mins"), 2), "minutes\n")
+
+
